@@ -25,14 +25,13 @@
 #include <KLocalizedString>
 
 K_PLUGIN_FACTORY(devInfoModuleFactory, registerPlugin<DevInfoPlugin>();)
-K_EXPORT_PLUGIN(devInfoModuleFactory("kcmdevinfo"))
 
 DevInfoPlugin::DevInfoPlugin(QWidget *parent, const QVariantList &)  : 
   KCModule(parent)
 {
   
   const KAboutData *about =
-  new KAboutData(i18n("kcmdevinfo"), i18n("KDE Solid Based Device Viewer"),
+  new KAboutData(i18n("kcmdevinfo"), i18n("Device Viewer"),
                   QStringLiteral("0.70"), QString(), KAboutLicense::GPL,
                   i18n("(c) 2010 David Hubner"));
 		  
